================================================================================
pypi-mobans-pkg
================================================================================

.. image:: https://api.travis-ci.org/moremoban/pypi-mobans-pkg.svg
   :target: http://travis-ci.org/moremoban/pypi-mobans-pkg

.. image:: https://codecov.io/github/moremoban/pypi-mobans-pkg/coverage.png
   :target: https://codecov.io/github/moremoban/pypi-mobans-pkg

.. image:: https://img.shields.io/gitter/room/gitterHQ/gitter.svg
   :target: https://gitter.im/chfw_moban/Lobby


The project packages `pypi-mobans <https://github.com/moremoban/pypi-mobans>`_, `gitignore <https://github.com/github/gitignore>`_ and distributes it via pypi.

Installation
================================================================================


You can install pypi-mobans-pkg via pip:

.. code-block:: bash

    $ pip install pypi-mobans-pkg


or clone it and install it:

.. code-block:: bash

    $ git clone https://github.com/moremoban/pypi-mobans-pkg.git
    $ cd pypi-mobans-pkg


Maintenance
==================

$ git submodule update --init --recursive
